@@ -92,10 +92,6 @@ tidy_wrap <- function(x, exponentiate, conf.level, tidy_fun) {
     )
   }
 
-  # looks for if p.value column is missing and adds NAs if so
-  missed <- base::setdiff("p.value", names(tidy_bit))
-  tidy_bit[missed] <- NA
-
   # otherwise returning original output
   return(tidy_bit)
 }
@@ -213,7 +209,7 @@ parse_fit <- function(fit, tidy, label, show_single_row) {
     ))
   }
 
-  # more  var labels -----------------------------------------------------------
+  # more var labels -----------------------------------------------------------
   # model.frame() strips variable labels from cox models.  this attempts
   # to grab the labels in another way
   labels_parent_frame <- tryCatch({
@@ -398,7 +394,13 @@ parse_fit <- function(fit, tidy, label, show_single_row) {
     )
 
   # returning final formatted tibble of results
-  map_dfr(result$table, ~.x)
+  df_result <- map_dfr(result$table, ~.x)
+
+  # need to attach the label and show_single_row evaluated lists to save out later
+  attr(df_result, "label") <- label
+  attr(df_result, "show_single_row") <- show_single_row
+
+  df_result
 }
 
 #' Adds refernce rows, and header rows for categorical and interaction variables
@@ -465,15 +467,17 @@ parse_final_touches <- function(group, group_lbl, single_row, var_type, data, mo
   }
 
   # keeping necessary vars and renaming
+  # vars to keep (in order)
+  cols_to_keep <-
+    c("variable", "var_type", "row_ref", "row_type", "label", "N",
+    "estimate", "conf.low", "conf.high", "p.value") %>%
+    intersect(c(names(result), "N", "var_type"))
   result %>%
     mutate(
       N = nrow(model_frame),
       var_type = var_type
     ) %>%
-    select(c(
-      "variable", "var_type", "row_ref", "row_type", "label", "N",
-      "estimate", "conf.low", "conf.high", "p.value"
-    ))
+    select(all_of(cols_to_keep))
 }
 
 #' Takes a vector and transforms to data frame with those column names
