@@ -15,11 +15,7 @@ test_that("expect error if no p value in table 1", {
 
   expect_error(
     add_q(table1),
-    glue(
-      "There are no p-values yet. You need to use the function add_p(), ",
-      "after tbl_summary() and before add_q()"
-    ),
-    fixed = TRUE
+    "*"
   )
 })
 
@@ -36,23 +32,30 @@ test_that("no errors/warnings with standard use after tbl_uvregression() and add
   expect_warning(add_q(uni_reg), NA)
 })
 
-
-
-test_that("expect error with no global p value in tbl_uvregression", {
-  uni_reg <- trial %>% tbl_uvregression(
-    method = lm,
-    y = age
-  )
-
-  expect_error(
-    add_q(uni_reg),
-    "You need global p-values first*",
-  )
-})
-
 test_that("add_q creates errors when non-function in input", {
   expect_error(
     add_q(uni_reg, pvalue_fun = mtcars),
     "*"
   )
 })
+
+
+
+test_that("Checking q-values against p.adjust", {
+  q_check1 <-
+    lm(marker ~ stage + age + grade + trt, trial) %>%
+    tbl_regression() %>%
+    add_q()
+  q_check2 <-
+    lm(marker ~ stage + age + grade + trt, trial) %>%
+    tbl_regression() %>%
+    add_q(method = "bonferroni")
+  expect_equal(
+    q_check1$table_body$q.value %>% discard(is.na),
+    q_check1$table_body$p.value %>% discard(is.na) %>% stats::p.adjust(method = "fdr")
+  )
+  expect_equal(
+    q_check2$table_body$q.value %>% discard(is.na),
+    q_check2$table_body$p.value %>% discard(is.na) %>% stats::p.adjust(method = "bonferroni")
+  )
+})
